@@ -334,7 +334,6 @@ func indexHandler(w http.ResponseWriter, r *http.Request) {
     <table>
         <thead>
             <tr>
-                <th>Instance</th>
                 <th>Type</th>
                 <th>Hostname</th>
                 <th>Status</th>
@@ -384,7 +383,6 @@ func indexHandler(w http.ResponseWriter, r *http.Request) {
 
 					html += fmt.Sprintf(`
             <tr>
-                <td style="font-family: monospace; font-size: 0.85em;">%s</td>
                 <td><span class="%s">%s</span></td>
                 <td>%s</td>
                 <td><span class="%s">%s</span></td>
@@ -394,7 +392,6 @@ func indexHandler(w http.ResponseWriter, r *http.Request) {
                 <td class="metric">%s</td>
                 <td class="metric">%s</td>
             </tr>`,
-						instance.InstanceID,
 						badgeClass,
 						instance.InstanceType,
 						instance.Hostname,
@@ -423,7 +420,7 @@ func indexHandler(w http.ResponseWriter, r *http.Request) {
 		if err != nil {
 			log.Printf("Failed to list jobs: %v\n", err)
 		} else if len(jobs) > 0 {
-			html += `<div class="section-title">Recent Jobs</div>`
+			html += `<div class="section-title">Recent Packaging Jobs</div>`
 			html += `
 			<table>
 				<thead>
@@ -442,10 +439,9 @@ func indexHandler(w http.ResponseWriter, r *http.Request) {
 
 			// Get actual task states from machinery
 			for _, job := range jobs {
-				// Query both build and repo task states
+				// Query both build and repo task states using machinery backend
 				buildState, repoState, currentStage := monitoring.GetJobStagesFromMachinery(
-					monitoringRegistry.GetContext(),
-					monitoringRegistry.GetClient(),
+					server.GetBackend(),
 					job.TaskUUID,
 				)
 
@@ -454,16 +450,20 @@ func indexHandler(w http.ResponseWriter, r *http.Request) {
 				job.RepoState = repoState
 				job.CurrentStage = currentStage
 
-				// Determine overall state
-				overallState := "PENDING"
+				// Determine overall state using same logic as BuildStatusHandler
+				var overallState string
 				if buildState == "FAILURE" {
-					overallState = "FAILURE"
-				} else if repoState == "FAILURE" {
-					overallState = "FAILURE"
+					overallState = "FAILED"
 				} else if buildState == "SUCCESS" && repoState == "SUCCESS" {
-					overallState = "SUCCESS"
-				} else if buildState == "STARTED" || repoState == "STARTED" {
-					overallState = "STARTED"
+					overallState = "DONE"
+				} else if buildState == "SUCCESS" && repoState == "FAILURE" {
+					overallState = "FAILED"
+				} else if buildState == "SUCCESS" && (repoState == "PENDING" || repoState == "RECEIVED" || repoState == "STARTED") {
+					overallState = "REPO"
+				} else if buildState != "" {
+					overallState = buildState
+				} else {
+					overallState = "PENDING"
 				}
 
 				job.State = overallState
@@ -472,16 +472,19 @@ func indexHandler(w http.ResponseWriter, r *http.Request) {
 				statusClass := ""
 				statusText := overallState
 				switch overallState {
-				case "SUCCESS":
+				case "DONE":
 					statusClass = "status-online"
-				case "FAILURE":
+				case "FAILED":
 					statusClass = "status-offline"
 					// Show which stage failed
 					if buildState == "FAILURE" {
-						statusText = "FAILURE (build)"
+						statusText = "FAILED (build)"
 					} else if repoState == "FAILURE" {
-						statusText = "FAILURE (repo)"
+						statusText = "FAILED (repo)"
 					}
+				case "REPO":
+					statusClass = "status-warning"
+					statusText = "REPO"
 				case "STARTED":
 					statusClass = "status-warning"
 					// Show which stage is running
@@ -703,6 +706,7 @@ func BuildStatusHandler(w http.ResponseWriter, r *http.Request) {
 	var UUID string
 	UUID = keys[0]
 
+	// Check build task state
 	buildSignature := tasks.Signature{
 		Name: "build",
 		UUID: UUID,
@@ -713,14 +717,121 @@ func BuildStatusHandler(w http.ResponseWriter, r *http.Request) {
 			},
 		},
 	}
-	// Recreate the AsyncResult instance using the signature and server.backend
-	car := result.NewAsyncResult(&buildSignature, server.GetBackend())
-	car.Touch()
-	taskState := car.GetState()
-	res := fmt.Sprintf("{ \"pipelineId\": \"" + taskState.TaskUUID + "\", \"state\": \"" + taskState.State + "\" }")
+	buildResult := result.NewAsyncResult(&buildSignature, server.GetBackend())
+	buildResult.Touch()
+	buildState := buildResult.GetState()
+
+	// Check repo task state
+	repoSignature := tasks.Signature{
+		Name: "repo",
+		UUID: UUID,
+	}
+	repoResult := result.NewAsyncResult(&repoSignature, server.GetBackend())
+	repoResult.Touch()
+	repoState := repoResult.GetState()
+
+	// Determine overall pipeline state
+	var pipelineState string
+	if buildState.State == "FAILURE" {
+		pipelineState = "FAILED"
+	} else if buildState.State == "SUCCESS" && repoState.State == "SUCCESS" {
+		pipelineState = "DONE"
+	} else if buildState.State == "SUCCESS" && repoState.State == "FAILURE" {
+		pipelineState = "FAILED"
+	} else if buildState.State == "SUCCESS" && (repoState.State == "PENDING" || repoState.State == "RECEIVED" || repoState.State == "STARTED") {
+		pipelineState = "REPO"
+	} else {
+		pipelineState = buildState.State
+	}
+
+	res := fmt.Sprintf("{ \"pipelineId\": \"%s\", \"state\": \"%s\" }", UUID, pipelineState)
 	fmt.Fprintf(w, res)
 }
 
+func RetryHandler(w http.ResponseWriter, r *http.Request) {
+	keys, ok := r.URL.Query()["uuid"]
+	if !ok {
+		w.WriteHeader(http.StatusBadRequest)
+		fmt.Fprintf(w, `{"error": "uuid parameter is required"}`)
+		return
+	}
+	taskUUID := keys[0]
+
+	// Check if monitoring is enabled
+	if !irgshConfig.Monitoring.Enabled || monitoringRegistry == nil {
+		w.WriteHeader(http.StatusServiceUnavailable)
+		fmt.Fprintf(w, `{"error": "monitoring is not enabled, retry requires job tracking"}`)
+		return
+	}
+
+	// Get job info from monitoring registry
+	job, err := monitoringRegistry.GetJob(taskUUID)
+	if err != nil {
+		w.WriteHeader(http.StatusNotFound)
+		fmt.Fprintf(w, `{"error": "job not found: %s"}`, taskUUID)
+		return
+	}
+
+	// Build the submission object from job info
+	submission := Submission{
+		TaskUUID:       job.TaskUUID,
+		Timestamp:      time.Now(),
+		PackageName:    job.PackageName,
+		PackageVersion: job.PackageVersion,
+		PackageURL:     job.PackageURL,
+		SourceURL:      job.SourceURL,
+		Maintainer:     job.Maintainer,
+		Component:      job.Component,
+		IsExperimental: job.IsExperimental,
+		PackageBranch:  job.PackageBranch,
+		SourceBranch:   job.SourceBranch,
+	}
+
+	jsonStr, err := json.Marshal(submission)
+	if err != nil {
+		log.Println(err.Error())
+		w.WriteHeader(http.StatusInternalServerError)
+		fmt.Fprintf(w, `{"error": "failed to marshal submission"}`)
+		return
+	}
+
+	buildSignature := tasks.Signature{
+		Name: "build",
+		UUID: submission.TaskUUID,
+		Args: []tasks.Arg{
+			{
+				Type:  "string",
+				Value: string(jsonStr),
+			},
+		},
+	}
+
+	repoSignature := tasks.Signature{
+		Name: "repo",
+		UUID: submission.TaskUUID,
+	}
+
+	chain, _ := tasks.NewChain(&buildSignature, &repoSignature)
+	_, err = server.SendChain(chain)
+	if err != nil {
+		log.Println("Could not send chain : " + err.Error())
+		w.WriteHeader(http.StatusInternalServerError)
+		fmt.Fprintf(w, `{"error": "failed to queue retry task: %s"}`, err.Error())
+		return
+	}
+
+	// Update job state to PENDING
+	if err := monitoringRegistry.UpdateJobState(taskUUID, "PENDING"); err != nil {
+		log.Printf("Failed to update job state: %v\n", err)
+	}
+
+	log.Printf("Job %s retried successfully\n", taskUUID)
+
+	payload := SubmitPayloadResponse{PipelineId: submission.TaskUUID}
+	jsonStr, _ = json.Marshal(payload)
+	fmt.Fprintf(w, string(jsonStr))
+}
+
 func artifactUploadHandler() http.HandlerFunc {
 	return http.HandlerFunc(func(w http.ResponseWriter, r *http.Request) {
 		var err error
